foreach pkg in fsx estout {
    capture which `pkg'
    if _rc==111 ssc install `pkg'
}

capture program drop runregs_scd
program define runregs_scd
    version 10.0

    /* Pooled Regressions */

    fsx *.pooled.scd.dta
    foreach file in `r(files)' {
      clear
      use `file'
      local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
      local model=regexs(1)
      eststo `model': quietly logit vote `0', vce(cluster statecd)
    }

    esttab using results.pooled.scd.csv, csv mtitles replace
    esttab using results.pooled.scd.txt, mtitles replace
    est clear

    fsx *.wide.scd.dta
    foreach file in `r(files)' {
      clear
      use `file'
      local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
      local model=regexs(1)
      eststo `model': quietly reg `0', robust
    }

    esttab using results.vhardprop.scd.csv, csv mtitles replace
    esttab using results.vhardprop.scd.txt, mtitles replace
    est clear

    fsx *.wide.scd.dta
    foreach file in `r(files)' {
      clear
      use `file'
      local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
      local model=regexs(1)
      capture: quietly logit vstable `0'
      if _rc==0 {
          eststo `model'
      }
    }

    esttab using results.vstable.scd.csv, csv mtitles replace
    esttab using results.vstable.scd.txt, mtitles replace
    est clear


    // ***************************
    // INDIVIDUAL VOTE REGRESSIONS
    // ***************************
    fsx *.wide.scd.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([^0-9]+)\.wide")
        local group=regexs(1)
        
        unab allvars: v*c
        local votes
        foreach var in `allvars' {
            if regexm("`var'", "v[0-9]+c") {
                local votes `votes' `var'
            }
        }
        foreach vote in `votes' {
            eststo: quietly logit `vote' `0', r
        }
        esttab using results.`group'.scd.csv, csv replace
        esttab using results.`group'.scd.txt, replace
        est clear
    }

end


capture program drop runregs_sl70
program define runregs_sl70
    version 10.0

    /* Pooled regressions */
    fsx h3*.pooled.sl.dta h4*.pooled.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
        local model=regexs(1)
        capture: quietly logit vote `0', vce(cluster state)
        if _rc==0 {
            eststo `model'
        }
    }
    esttab using results.pooled.sl70.csv, csv mtitles replace
    esttab using results.pooled.sl70.txt, mtitles replace
    est clear

    /* Wide regressions proportion hard votes */
    fsx h3*.wide.sl.dta h4*.wide.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
        local model=regexs(1)
        capture: quietly reg vhardprop `0', vce(cluster state)
        if _rc==0 {
            eststo `model'
        }
    }
    esttab using results.vhardprop.sl70.csv, csv mtitles replace
    esttab using results.vhardprop.sl70.txt, mtitles replace
    est clear

    /* Wide regressions stable votes only */
    fsx h3*.wide.sl.dta h4*.wide.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
        local model=regexs(1)
        capture: quietly vstable `0', vce(cluster state)
        if _rc==0 {
            eststo `model'
        }
    }
    esttab using results.vstable.sl70.csv, csv mtitles replace
    esttab using results.vstable.sl70.txt, mtitles replace
    est clear

    // ***************************
    // INDIVIDUAL VOTE REGRESSIONS
    // ***************************
    fsx h3*.wide.sl.dta h4*.wide.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([^0-9]+)\.wide")
        local group=regexs(1)
        
        unab allvars: v*c
        local votes
        foreach var in `allvars' {
            if regexm("`var'", "v[0-9]+c") {
                local votes `votes' `var'
            }
        }
        foreach vote in `votes' {
            eststo: quietly logit `vote' `0', vce(cluster state)
        }
        esttab using results.`group'.sl.csv, csv replace
        esttab using results.`group'.sl.txt, replace
        est clear
    }
end

capture program drop runregs_sl90
program define runregs_sl90
    version 10.0

    /* Pooled regressions */
    fsx h5*.pooled.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
        local model=regexs(1)
        capture: quietly logit vote `0', vce(cluster state)
        if _rc==0 {
            eststo `model'
        }
    }
    esttab using results.pooled.sl90.csv, csv mtitles replace
    esttab using results.pooled.sl90.txt, mtitles replace
    est clear

    /* Wide regressions proportion hard votes */
    fsx h5*.wide.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
        local model=regexs(1)
        capture: quietly reg vhardprop `0', vce(cluster state)
        if _rc==0 {
            eststo `model'
        }
    }
    esttab using results.vhardprop.sl90.csv, csv mtitles replace
    esttab using results.vhardprop.sl90.txt, mtitles replace
    est clear

    /* Wide regressions stable votes only */
    fsx h5*.wide.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([a-z]+)\.")
        local model=regexs(1)
        capture: quietly vstable `0', vce(cluster state)
        if _rc==0 {
            eststo `model'
        }
    }
    esttab using results.vstable.sl90.csv, csv mtitles replace
    esttab using results.vstable.sl90.txt, mtitles replace
    est clear

    // ***************************
    // INDIVIDUAL VOTE REGRESSIONS
    // ***************************
    fsx h5*.wide.sl.dta
    foreach file in `r(files)' {
        clear
        use `file'
        local tmp=regexm("`file'", "[0-9]+\.([^0-9]+)\.wide")
        local group=regexs(1)
        
        unab allvars: v*c
        local votes
        foreach var in `allvars' {
            if regexm("`var'", "v[0-9]+c") {
                local votes `votes' `var'
            }
        }
        foreach vote in `votes' {
            eststo: quietly logit `vote' `0', vce(cluster state)
        }
        esttab using results.`group'.sl.csv, csv replace
        esttab using results.`group'.sl.txt, replace
        est clear
    }
end
// lastline
